@@ -18,9 +18,7 @@ from tests.properties import Properties
 import uuid
 import re
 
-
 def test_org_add():
-
     runner = CliRunner()
 
     props = Properties()
@@ -28,11 +26,14 @@ def test_org_add():
     cluster_name = "qa"
     org_name = "zQA-CLI-{}".format(uuid.uuid4())
 
-    runner.invoke(add_cluster,
-                  '--remote "{}" --username "{}" --password "{}" --name "{}" --assetsync True'.format(
-                      props.api_url,
-                      props.user_name,
-                      props.user_password, cluster_name))
+    confi = '--remote "{}" --username "{}" --password "{}" --name "{}" --assetsync True'.format(
+        props.api_url,
+        props.user_name,
+        props.user_password,
+        cluster_name
+    )
+
+    runner.invoke(add_cluster, confi)
 
     runner.invoke(login, '--remote "{}"'.format(cluster_name))
 
